@@ -27,7 +27,7 @@ class NomadBlogMixin(object):
 
 class PostList(NomadBlogMixin, ListView):
     model = POST_MODEL
-    template_name = 'nomadblog/post_list.html'
+    paginate_by = getattr(settings, 'POST_PAGINATE_BY', 25)
 
     def get_queryset(self):
         qs = super(PostList, self).get_queryset()
@@ -36,7 +36,6 @@ class PostList(NomadBlogMixin, ListView):
 
 class PostDetail(NomadBlogMixin, DetailView):
     model = POST_MODEL
-    template_name = 'nomadblog/post_detail.html'
 
     def get_object(self, queryset=None):
         queryset = self.get_queryset().filter(bloguser__blog=self.blog)
@@ -45,11 +44,13 @@ class PostDetail(NomadBlogMixin, DetailView):
 
 class CategoriesList(NomadBlogMixin, ListView):
     model = Category
+    paginate_by = getattr(settings, 'CATEGORY_PAGINATE_BY', 25)
 
 
 class PostsByCategoryList(NomadBlogMixin, ListView):
     model = POST_MODEL
     template_name = 'nomadblog/post_list_by_category.html'
+    paginate_by = getattr(settings, 'POST_PAGINATE_BY', 25)
 
     def get_queryset(self, *args, **kwargs):
         qs = super(PostsByCategoryList, self).get_queryset()
